@@ -1,12 +1,13 @@
 package Text::TransMetaphone::ar;
-
 use utf8;
+
 BEGIN
 {
 	use strict;
+	use warnings;
 	use vars qw( $VERSION $LocaleRange );
 
-	$VERSION = '0.01';
+	$VERSION = '0.08';
 
 	$LocaleRange = qr/(\p{InArabic}|\p{InArabicPresentationFormsA}|\p{InArabicPresentationFormsB})/;
 
@@ -133,10 +134,12 @@ sub reverse_key
 __END__
 
 
+=encoding utf8
+
 
 =head1 NAME
 
-Text::TransMetaphone::ar - Transcribe Arabic words into IPA symbols.
+Text::TransMetaphone::ar – Transcribe Arabic words into IPA symbols.
 
 =head1 SYNOPSIS
 
@@ -162,10 +165,12 @@ second key strips the "w" IPA symbol under vowel rules.  One key *should* be
 created for each "w" substitution, this will be fixed in a future release.
 The module will be updated as more rules of Arabic orthography are learnt.
 
-=head1 COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
 
-This module is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+Copyright (c) 2003-2025, Daniel Yacob C<< <dyacob@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
 
 =head1 BUGS
 
